@@ -1,15 +1,13 @@
-from gym.envs.registration import register
+from gymnasium.envs.registration import register
 
 register(
     id='Inventory-v1',
-    entry_point='cpagym.envs.grid_world:InventoryEnv',
+    entry_point='cpagym.envs.inventory_env:InventoryEnv',
 )
-
 register(
     id='forex-v1',
     entry_point='cpagym.envs.forex_env:ForexEnv',
 )
-
 register(
     id='stocks-v1',
     entry_point='cpagym.envs.stocks_env:StocksEnv',
@@ -21,4 +19,8 @@ register(
 register(
     id='AsymmetricInfo-v1',
     entry_point='cpagym.envs.asymmetricInfo_env:AsymmetricInfoEnv',
+)
+register(
+    id='Moral_Hazard-v1',
+    entry_point='cpagym.envs.moral_hazard_env:Moral_HazardEnv',
 )
\ No newline at end of file
